@@ -86,7 +86,7 @@
 #define KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED
-#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
+#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED_WARNINGS
 #  define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x54f00
+#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -145,8 +145,33 @@
 #else
 #  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_69(text)
 #endif
+
+#if KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE >= 0x55000
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_80(text) KWINDOWSYSTEM_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_80(text)
+#endif
+
+#if KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE >= 0x55100
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_81(text) KWINDOWSYSTEM_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_81(text)
+#endif
+
+#if KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE >= 0x55200
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_82(text) KWINDOWSYSTEM_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWINDOWSYSTEM_DEPRECATED_VERSION_5_82(text)
+#endif
 #define KWINDOWSYSTEM_DEPRECATED_VERSION_5(minor, text)      KWINDOWSYSTEM_DEPRECATED_VERSION_5_##minor(text)
 #define KWINDOWSYSTEM_DEPRECATED_VERSION(major, minor, text) KWINDOWSYSTEM_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWINDOWSYSTEM_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWINDOWSYSTEM_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KWINDOWSYSTEM_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KWINDOWSYSTEM_DEPRECATED_VERSION(major, minor, text)
+#  define KWINDOWSYSTEM_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWINDOWSYSTEM_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KWINDOWSYSTEM_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KWINDOWSYSTEM_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KWINDOWSYSTEM_EXPORT_H */
